@@ -32,7 +32,7 @@ __version__ = get_versions()
 _backend = None
 
 
-def init(backend=None, api_token=None):
+def init(backend=None, api_token=None, internal_login=True):
     with __lock:
         global _backend
 
@@ -42,7 +42,7 @@ def init(backend=None, api_token=None):
             #     backend = OfflineBackend()
 
             # elif backend_name is None:
-            _backend = HostedBackend(api_token)
+            _backend = HostedBackend(api_token, internal_login=internal_login)
 
             # else:
             #     raise InvalidBackend(backend_name)
@@ -124,7 +124,7 @@ def get_app():
 
 
 def create_dataset(name, path, data_type=constants.DataType.TYPE_FILE.value, visibility=Visibility.PRIVATE.value,
-                   desc=None):
+                   desc=None, label_type=None):
     """
     创建数据集
     :param name: 数据集名称
@@ -134,7 +134,7 @@ def create_dataset(name, path, data_type=constants.DataType.TYPE_FILE.value, vis
     :param desc: 数据集详情
     :return: Dataset对象
     """
-    return _get_backend().create_dataset(name, path, data_type, visibility, desc)
+    return _get_backend().create_dataset(name, path, data_type, visibility, desc, label_type)
 
 
 def get_dataset(dataset_id):
@@ -262,7 +262,7 @@ def list_models():
     return _get_backend().list_models()
 
 
-def update_dataset(dataset_id, name, zone, desc=None):
+def update_dataset(dataset_id, name, zone, desc=None, label_type=None):
     """
     更新数据集id
     :param dataset_id:
@@ -271,7 +271,7 @@ def update_dataset(dataset_id, name, zone, desc=None):
     :param desc:
     :return:
     """
-    return _get_backend().update_dataset(dataset_id, name, zone, desc)
+    return _get_backend().update_dataset(dataset_id, name, zone, desc, label_type)
 
 
 def delete_dataset(dataset_id):
