@@ -886,23 +886,30 @@ class HostedBackend(Backend):
                 return 's3path不存在'
             s3path = s3path.split('s3://')
             s3path = '/' + s3path[1] + '/'
+            if path[-1] == '/' and path != '/' and path != './':
+                change_path = path[0:-1]
+            else:
+                change_path = path
             with Pool(5) as pool:
-                if '.' not in path:
-                    resultinfo, dir = self._list_dir_model_artifacts(repo_id, path, [], [])
+                if '.' not in path or path == '/' or path == './':
+                    resultinfo, dir = self._list_dir_model_artifacts(repo_id, change_path, [], [])
                     if resultinfo == []:
                         raise Exception(f"当前目录下无文件，请检查目录参数{path}")
                     for i in dir:
                         if i[0] != '/':
                             continue
-                        if path[-1] != '/':
+                        if path[-1] != '/' or path == '/' or path == './':
                             if not os.path.exists(destination + i):
                                 os.makedirs(destination + i)
                     for result in resultinfo:
                         file_path = minio_path + s3path + result
-                        file_name = result.split('/')
-                        des_path = file_name[0]
+                        file_name = result.rsplit('/', 1)
+                        if path[-1] != '/' or path == '/' or path == './':
+                            des_path = file_name[0]
+                        else:
+                            des_path = ''
                         file_name = file_name[-1]
-                        if '/' in result:
+                        if '/' in result or path == '/' or path == './':
                             urls.append((file_path, destination + '/' + des_path, file_name))
                         else:
                             urls.append((file_path, destination, file_name))
@@ -910,7 +917,7 @@ class HostedBackend(Backend):
                     path_status = self._check_file_status(repo_id, path)
                     if path_status is False:
                         raise Exception(f"当前目录下不存在文件，请检查目录参数:{path}")
-                    if '/' in path:
+                    if '/' in path and path != '/' and path :
                         split_path = path.split('/')
                         file_name = split_path[-1]
                         file_path = minio_path + s3path + path
@@ -941,10 +948,8 @@ class HostedBackend(Backend):
             s3path = self._get_repo_s3path(repo_id)
             if s3path is None:
                 return '当前模型库下无文件，请检查模型库ID或模型库文件是否已经存在'
-            s3path = s3path.split("/")
-            s3path.pop()
-            s3path.pop(0)
-            model_path = "/".join(s3path)
+            s3path = s3path.split('s3://')
+            s3path = '/' + s3path[1] + '/'
             with Pool(5) as pool:
                 resultinfo, dir = self._list_dir_model_artifacts(repo_id, None, [], [])
                 for i in dir:
@@ -953,11 +958,15 @@ class HostedBackend(Backend):
                     if not os.path.exists(destination + i):
                         os.makedirs(destination + i)
                 for result in resultinfo:
-                    result_path = result.rsplit('/', 1)
-                    des_path = result_path[0]
-                    result_path = result_path[-1]
-                    file_path = minio_path + model_path + '/' + des_path + "/" + result_path
-                    urls.append((file_path, destination + '/' + des_path, result_path))
+                    if '/' in result:
+                        result_path = result.rsplit('/', 1)
+                        des_path = result_path[0]
+                        result_path = result_path[-1]
+                        file_path = minio_path + s3path + '/' + des_path + "/" + result_path
+                        urls.append((file_path, destination + '/' + des_path, result_path))
+                    else:
+                        file_path = minio_path + s3path + result
+                        urls.append((file_path, destination , result))
                 pool.map(self._url_download, urls)
                 pool.close()
                 pool.join()
@@ -973,7 +982,7 @@ class HostedBackend(Backend):
         :return: 返回文件，图片数据集文件，文件夹列表
         """
         res = self._session.get(url=f'{self.api_address}/training/run/{repo_id}/artifacts/list?path={path}')
-        if not path:
+        if not path or path == './' or path == '/':
             res = self._session.get(url=f'{self.api_address}/training/run/{repo_id}/artifacts/list')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
@@ -1002,6 +1011,8 @@ class HostedBackend(Backend):
         :return: 返回文件，图片数据集文件，文件夹列表
         """
         res = self._session.get(url=f'{self.api_address}/training/run/{repo_id}/artifacts/status?file={path}')
+        if path == '/' or path == './':
+            res = self._session.get(url=f'{self.api_address}/training/run/{repo_id}/artifacts/status')
         if res.json()["message"]:
             raise Exception(res.json()["message"])
         return res.json()['data']
